@@ -56,6 +56,7 @@ public:
 
     void addFailedMessage(const QString &err);
     void addOkMessage(const QString &msg);
+    void addNormalMessage(const QString &msg);
 
     void setModified(bool b);
     bool isModified() const;
@@ -67,7 +68,6 @@ public:
     bool hasSelection() const;
 
     void checkSpelling();
-    void share();
     void import();
     void lowerCase();
     void upperCase();
@@ -81,6 +81,13 @@ public:
     void debugSieveScript();
     void zoomReset();
     bool isWordWrap() const;
+
+    void updateOriginalScript();
+    void print();
+    void printPreview();
+
+    bool printSupportEnabled() const;
+    bool isTextEditor() const;
 public Q_SLOTS:
     void find();
     void replace();
@@ -93,8 +100,8 @@ public Q_SLOTS:
     void goToLine();
     void slotSaveAs();
     void slotImport();
-    void slotUploadScripts();
-    void slotAutoGenerateScripts();
+    void slotShareScript();
+    void slotCreateRulesGraphically();
     void slotCheckSyntax();
     void comment();
     void uncomment();
@@ -116,6 +123,7 @@ Q_SIGNALS:
     void redoAvailable(bool);
     void copyAvailable(bool);
     void changeModeEditor(bool);
+    void sieveEditorTabCurrentChanged();
 private:
     void changeSwitchButtonText();
     void changeMode(EditorMode mode);
@@ -127,9 +135,9 @@ private:
     QLineEdit *mScriptName;
     QAction *mCheckSyntax;
     QAction *mSwitchMode;
-    QAction *mAutoGenerateScript;
+    QAction *mCreateRulesGraphically;
     QAction *mSaveAs;
-    QAction *mUpload;
+    QAction *mShareScript;
 #if !defined(NDEBUG)
     QAction *mGenerateXml;
 #endif
